/*************************************************** 
  What does the Fox say? See N' Say

  This is my entry for the Useless Machine Contest sponsered by MacroFab Design.

  Summary:
    I gutted a Fisher-Price Little People World of Animals See N' Say.
    Then added an Adafruit METRO 328 (Prod. ID 2488) and Adafruit "Music Maker" MP3 shield (Prod. ID 1790).
    Instead of playing animal sounds it plays random sound clips from "The Fox" by Ylvis.
    None of these clips are sounds that a real fox would make and is completely useless for educating children.

  This sketch is based on the player_simple example provided by Adafruit.  That file in it's entirety is included at the end of this file.

  Joneil Kimball
  AKA:  Mutton Chops Joe
  8/27/19
 ****************************************************/

// include SPI, MP3 and SD libraries
#include <SPI.h>
#include <Adafruit_VS1053.h>
#include <SD.h>

// define the pins used
//#define CLK 13       // SPI Clock, shared with SD card
//#define MISO 12      // Input data, from VS1053/SD card
//#define MOSI 11      // Output data, to VS1053/SD card
// Connect CLK, MISO and MOSI to hardware SPI pins. 
// See http://arduino.cc/en/Reference/SPI "Connections"

// These are the pins used for the music maker shield
#define SHIELD_RESET  -1      // VS1053 reset pin (unused!)
#define SHIELD_CS     7      // VS1053 chip select pin (output)
#define SHIELD_DCS    6      // VS1053 Data/command select pin (output)

// These are common pins between breakout and shield
#define CARDCS 4     // Card chip select pin
// DREQ should be an Int pin, see http://arduino.cc/en/Reference/attachInterrupt
#define DREQ 3       // VS1053 Data request, ideally an Interrupt pin

#define btn_speak 8       //input pin for button to start speaking

Adafruit_VS1053_FilePlayer musicPlayer = Adafruit_VS1053_FilePlayer(SHIELD_RESET, SHIELD_CS, SHIELD_DCS, DREQ, CARDCS);

//Variables
boolean handlePulled;
  
void setup() {
  pinMode(btn_speak, INPUT_PULLUP);

  handlePulled = false;
  
  Serial.begin(9600);
  Serial.println("What does the Fox say?");

  if (! musicPlayer.begin()) { // initialise the music player
     Serial.println(F("Couldn't find VS1053, do you have the right pins defined?"));
     while (1);
  }
  Serial.println(F("VS1053 found"));
  
   if (!SD.begin(CARDCS)) {
    Serial.println(F("SD failed, or not present"));
    while (1);  // don't do anything more
  }

  // list files
  printDirectory(SD.open("/"), 0);
  
  // Set volume for left, right channels. lower numbers == louder volume!
  // We want the volume pretty high.  The toys when I was a kid were deafening.
  // And we want the amplifier to start clipping to reduce audio quality to cheap toy levels.
  musicPlayer.setVolume(10,10);

  // If DREQ is on an interrupt pin (on uno, #2 or #3) we can do background
  // audio playing
  musicPlayer.useInterrupt(VS1053_FILEPLAYER_PIN_INT);  // DREQ int
  
}

void loop() {

  if (digitalRead(btn_speak) == LOW and !handlePulled and !musicPlayer.playingMusic){
    delay(10);
    handlePulled = !handlePulled;
    Serial.println(F("Handle pulled."));
  }

  // Play a random clip when the handle is released.
  if (digitalRead(btn_speak) == HIGH and handlePulled){
    handlePulled = !handlePulled;
    Serial.println(F("Handle released."));
    delay(10);
    // I thought having a higher range would make it more random.  It feels slightly more random.  Maybe.
    switch (random(900)){
      case 0 ... 99:
        musicPlayer.startPlayingFile("/cachow.mp3");
        Serial.println("Playing cachow.mp3.");
        break;
      case 100 ... 199:
        musicPlayer.startPlayingFile("/hotheho.mp3");
        Serial.println("Playing hotheho.mp3.");
        break;
      case 200 ... 299:
        musicPlayer.startPlayingFile("/pahpow.mp3");
        Serial.println("Playing pahpow.mp3.");
        break;
      case 300 ... 399:
        musicPlayer.startPlayingFile("/ringding.mp3");
        Serial.println("Playing ringding.mp3.");
        break;
      case 400 ... 499:
        musicPlayer.startPlayingFile("/wahcacow.mp3");
        Serial.println("Playing wahcacow.mp3.");
        break;
      case 500 ... 599:
        musicPlayer.startPlayingFile("/yepyip.mp3");
        Serial.println("Playing yepyip.mp3.");
        break;
      case 600 ... 699:
        musicPlayer.startPlayingFile("/ahhehahe.mp3");
        Serial.println("Playing ahhehahe.mp3.");
        break;
      case 700 ... 799:
        musicPlayer.startPlayingFile("/ahooh.mp3");
        Serial.println("Playing ahooh.mp3.");
        break;
      case 800 ... 899:
        musicPlayer.startPlayingFile("/beebop.mp3");
        Serial.println("Playing beebop.mp3.");
        break;
    }
  }
}


/// File listing helper
void printDirectory(File dir, int numTabs) {
   while(true) {
     
     File entry =  dir.openNextFile();
     if (! entry) {
       // no more files
       //Serial.println("**nomorefiles**");
       break;
     }
     for (uint8_t i=0; i<numTabs; i++) {
       Serial.print('\t');
     }
     Serial.print(entry.name());
     if (entry.isDirectory()) {
       Serial.println("/");
       printDirectory(entry, numTabs+1);
     } else {
       // files have sizes, directories do not
       Serial.print("\t\t");
       Serial.println(entry.size(), DEC);
     }
     entry.close();
   }
}

/*************************************************** 
//  This is an example for the Adafruit VS1053 Codec Breakout
//
//  Designed specifically to work with the Adafruit VS1053 Codec Breakout 
//  ----> https://www.adafruit.com/products/1381
//
//  Adafruit invests time and resources providing this open source code, 
//  please support Adafruit and open-source hardware by purchasing 
//  products from Adafruit!
//
//  Written by Limor Fried/Ladyada for Adafruit Industries.  
//  BSD license, all text above must be included in any redistribution
// ****************************************************/
//
//// include SPI, MP3 and SD libraries
//#include <SPI.h>
//#include <Adafruit_VS1053.h>
//#include <SD.h>
//
//// define the pins used
////#define CLK 13       // SPI Clock, shared with SD card
////#define MISO 12      // Input data, from VS1053/SD card
////#define MOSI 11      // Output data, to VS1053/SD card
//// Connect CLK, MISO and MOSI to hardware SPI pins. 
//// See http://arduino.cc/en/Reference/SPI "Connections"
//
//// These are the pins used for the breakout example
//#define BREAKOUT_RESET  9      // VS1053 reset pin (output)
//#define BREAKOUT_CS     10     // VS1053 chip select pin (output)
//#define BREAKOUT_DCS    8      // VS1053 Data/command select pin (output)
//// These are the pins used for the music maker shield
//#define SHIELD_RESET  -1      // VS1053 reset pin (unused!)
//#define SHIELD_CS     7      // VS1053 chip select pin (output)
//#define SHIELD_DCS    6      // VS1053 Data/command select pin (output)
//
//// These are common pins between breakout and shield
//#define CARDCS 4     // Card chip select pin
//// DREQ should be an Int pin, see http://arduino.cc/en/Reference/attachInterrupt
//#define DREQ 3       // VS1053 Data request, ideally an Interrupt pin
//
//Adafruit_VS1053_FilePlayer musicPlayer = 
//  // create breakout-example object!
//  Adafruit_VS1053_FilePlayer(BREAKOUT_RESET, BREAKOUT_CS, BREAKOUT_DCS, DREQ, CARDCS);
//  // create shield-example object!
//  //Adafruit_VS1053_FilePlayer(SHIELD_RESET, SHIELD_CS, SHIELD_DCS, DREQ, CARDCS);
//  
//void setup() {
//  Serial.begin(9600);
//  Serial.println("Adafruit VS1053 Simple Test");
//
//  if (! musicPlayer.begin()) { // initialise the music player
//     Serial.println(F("Couldn't find VS1053, do you have the right pins defined?"));
//     while (1);
//  }
//  Serial.println(F("VS1053 found"));
//  
//   if (!SD.begin(CARDCS)) {
//    Serial.println(F("SD failed, or not present"));
//    while (1);  // don't do anything more
//  }
//
//  // list files
//  printDirectory(SD.open("/"), 0);
//  
//  // Set volume for left, right channels. lower numbers == louder volume!
//  musicPlayer.setVolume(20,20);
//
//  // Timer interrupts are not suggested, better to use DREQ interrupt!
//  //musicPlayer.useInterrupt(VS1053_FILEPLAYER_TIMER0_INT); // timer int
//
//  // If DREQ is on an interrupt pin (on uno, #2 or #3) we can do background
//  // audio playing
//  musicPlayer.useInterrupt(VS1053_FILEPLAYER_PIN_INT);  // DREQ int
//  
//  // Play one file, don't return until complete
//  Serial.println(F("Playing track 001"));
//  musicPlayer.playFullFile("/track001.mp3");
//  // Play another file in the background, REQUIRES interrupts!
//  Serial.println(F("Playing track 002"));
//  musicPlayer.startPlayingFile("/track002.mp3");
//}
//
//void loop() {
//  // File is playing in the background
//  if (musicPlayer.stopped()) {
//    Serial.println("Done playing music");
//    while (1) {
//      delay(10);  // we're done! do nothing...
//    }
//  }
//  if (Serial.available()) {
//    char c = Serial.read();
//    
//    // if we get an 's' on the serial console, stop!
//    if (c == 's') {
//      musicPlayer.stopPlaying();
//    }
//    
//    // if we get an 'p' on the serial console, pause/unpause!
//    if (c == 'p') {
//      if (! musicPlayer.paused()) {
//        Serial.println("Paused");
//        musicPlayer.pausePlaying(true);
//      } else { 
//        Serial.println("Resumed");
//        musicPlayer.pausePlaying(false);
//      }
//    }
//  }
//
//  delay(100);
//}
//
//
///// File listing helper
//void printDirectory(File dir, int numTabs) {
//   while(true) {
//     
//     File entry =  dir.openNextFile();
//     if (! entry) {
//       // no more files
//       //Serial.println("**nomorefiles**");
//       break;
//     }
//     for (uint8_t i=0; i<numTabs; i++) {
//       Serial.print('\t');
//     }
//     Serial.print(entry.name());
//     if (entry.isDirectory()) {
//       Serial.println("/");
//       printDirectory(entry, numTabs+1);
//     } else {
//       // files have sizes, directories do not
//       Serial.print("\t\t");
//       Serial.println(entry.size(), DEC);
//     }
//     entry.close();
//   }
//}
